changeset 748:b01e5b5f851a draft

New tests added into BitBltUsingBgColor.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Mon, 10 Aug 2015 13:01:10 +0200
parents bfdcbd1179ce
children ee70173c9080
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 65 insertions(+), 60 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Thu Aug 06 10:02:33 2015 +0200
+++ b/ChangeLog	Mon Aug 10 13:01:10 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-10  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	New tests added into BitBltUsingBgColor.
+
 2015-08-06  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Aug 06 10:02:33 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Mon Aug 10 13:01:10 2015 +0200
@@ -9601,7 +9601,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9610,13 +9610,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType3ByteBGR(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -9625,13 +9625,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -9640,13 +9640,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -9655,13 +9655,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -9670,13 +9670,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -9685,13 +9685,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -9700,13 +9700,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -9715,13 +9715,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -9730,9 +9730,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.white);
+    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.white);
     }
 
     /**
@@ -9601,7 +9601,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      * Background color is set to Color.white.
      *